aboutsummaryrefslogtreecommitdiff
path: root/src/web/views/feed.py
diff options
context:
space:
mode:
authorCédric Bonhomme <cedric@cedricbonhomme.org>2016-11-14 07:39:36 +0100
committerCédric Bonhomme <cedric@cedricbonhomme.org>2016-11-14 07:39:36 +0100
commit71cb70e914ed4ba61caafe11cf9bf33f4fb3d27f (patch)
tree31e6ac6896058ec4248c3c64c744161f4e26c326 /src/web/views/feed.py
parentVarious improvements for the public pages and the private profile edition page. (diff)
downloadnewspipe-71cb70e914ed4ba61caafe11cf9bf33f4fb3d27f.tar.gz
newspipe-71cb70e914ed4ba61caafe11cf9bf33f4fb3d27f.tar.bz2
newspipe-71cb70e914ed4ba61caafe11cf9bf33f4fb3d27f.zip
Better checks for the public pages.
Diffstat (limited to 'src/web/views/feed.py')
-rw-r--r--src/web/views/feed.py5
1 files changed, 3 insertions, 2 deletions
diff --git a/src/web/views/feed.py b/src/web/views/feed.py
index 6bc4afe1..3edb942e 100644
--- a/src/web/views/feed.py
+++ b/src/web/views/feed.py
@@ -80,10 +80,11 @@ def feed(feed_id=None):
@etag_match
def feed_pub(feed_id=None):
"""
- Presents details of a pubic feed.
+ Presents details of a pubic feed if the profile of the owner is also
+ public.
"""
feed = FeedController(None).get(id=feed_id)
- if feed.private:
+ if feed.private or not feed.user.is_public_profile:
return render_template('errors/404.html'), 404
return feed_view(feed_id, None)
bgstack15